<?php
namespace Ak\Mailchimp;

use Laminas\Hydrator\ClassMethodsHydrator;
use Laminas\Hydrator\ReflectionHydrator;
use Laminas\ServiceManager\Factory\InvokableFactory;

/**
 * Pruža konfiguraciju komponente.
 *
 * @package Ak\Mailchimp
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mailchimp
 */
final class ConfigProvider
{
    /**
     * Vraća konfiguraciju
     *
     * @return array
     */
    public function __invoke(): array
    {
        return [
            'mailchimp' => $this->getMailchimpConfig(),
            'dependencies' => $this->getDependencies(),
            'hydrators' => $this->getHydrators(),
        ];
    }

    public function getMailchimpConfig(): array
    {
        return [
            'data_center' => '',
            'username' => '',
            'api_key' => '',
        ];
    }

    public function getDependencies(): array
    {
        return [
            'aliases' => [
                'mailchimp.lists' => Gateway\MailingListGateway::class,
            ],

            'factories' => [
                Gateway\MailingListGateway::class => Gateway\GatewayFactory::class,
                'mailchimp.http' => Service\HttpClientFactory::class,
            ],
        ];
    }

    public function getHydrators(): array
    {
        return [
            'aliases' => [
                Entity\MailingList::class                            => Hydrator\Entity\MailingListHydrator::class,
                Entity\MailingList\CampaignDefaults::class           => ClassMethodsHydrator::class,
                Entity\MailingList\Contact::class                    => ClassMethodsHydrator::class,
                Entity\MailingList\Stats::class                      => Hydrator\Entity\MailingList\StatsHydrator::class,
                Entity\MailingList\Member::class                     => Hydrator\Entity\MailingList\MemberHydrator::class,
                Entity\MailingList\Member\Location::class            => ReflectionHydrator::class,
                Entity\MailingList\Member\MarketingPermission::class => ClassMethodsHydrator::class,
                Entity\MailingList\Member\Stats::class               => ReflectionHydrator::class,

                Response\GetListMembersResponse::class => Hydrator\Response\GetListMembersHydrator::class,
                Response\GetListsResponse::class => Hydrator\Response\GetListsHydrator::class,
            ],

            'factories' => [
                Hydrator\Entity\MailingListHydrator::class        => InvokableFactory::class,
                Hydrator\Entity\MailingList\StatsHydrator::class  => InvokableFactory::class,
                Hydrator\Entity\MailingList\MemberHydrator::class => InvokableFactory::class,

                Hydrator\Response\GetListMembersHydrator::class => InvokableFactory::class,
                Hydrator\Response\GetListsHydrator::class => InvokableFactory::class,
            ],
        ];
    }
}
