<?php
namespace Ak\Mailchimp\Hydrator\Entity\MailingList;

use Ak\Mailchimp\Entity\MailingList\Member\Location;
use Ak\Mailchimp\Entity\MailingList\Member\MarketingPermission;
use Ak\Mailchimp\Entity\MailingList\Member\Note;
use Ak\Mailchimp\Entity\MailingList\Member\Stats;
use DateTime;
use Laminas\Hydrator\ClassMethodsHydrator;
use Laminas\Hydrator\ReflectionHydrator;
use Laminas\Hydrator\Strategy\CollectionStrategy;
use Laminas\Hydrator\Strategy\DateTimeFormatterStrategy;
use Laminas\Hydrator\Strategy\HydratorStrategy;

/**
 * Hidrira pretplatnike liste.
 *
 * @package Ak\Mailchimp\Hydrator\Entity\MailingList
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mailchimp
 */
final class MemberHydrator extends ReflectionHydrator
{
    /**
     * Konstruktor.
     */
    public function __construct()
    {
        $datetimeStrategy = new DateTimeFormatterStrategy(DateTime::ISO8601);

        $this->addStrategy('stats', new HydratorStrategy(new ClassMethodsHydrator(), Stats::class));
        $this->addStrategy('timestamp_signup', $datetimeStrategy);
        $this->addStrategy('timestamp_opt', $datetimeStrategy);
        $this->addStrategy('last_changed', $datetimeStrategy);
        $this->addStrategy('location', new HydratorStrategy(new ReflectionHydrator(), Location::class));
        $this->addStrategy('marketing_permissions', new CollectionStrategy(new ClassMethodsHydrator(), MarketingPermission::class));
        $this->addStrategy('last_note', new HydratorStrategy(new ReflectionHydrator(), Note::class));
    }
}
