<?php
namespace AkTest\Mailchimp\Gateway;

use AkTest\Mailchimp\AbstractTestCase;
use GuzzleHttp\Client;
use GuzzleHttp\Handler\MockHandler;
use GuzzleHttp\HandlerStack;
use GuzzleHttp\Psr7\Message;
use Laminas\ServiceManager\ServiceManager;

/**
 * Class AbstractGatewayTest
 *
 * @package AkTest\Mailchimp\Gateway
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/mailchimp
 */
abstract class AbstractGatewayTestCase extends AbstractTestCase
{
    protected function getMockHttpClient(array $responses): Client
    {
        $responses = array_map(function($response) {
            if (is_string($response)) {
                if (file_exists($response)) {
                    $response = file_get_contents($response);
                }

                $response = Message::parseResponse($response);
            }

            return $response;
        }, $responses);

        return new Client([
            'http_errors' => false,
            'handler' => HandlerStack::create(new MockHandler($responses)),
        ]);
    }

    protected function getContainerWithMockedHttpClient(array $responses): ServiceManager
    {
        return $this->getContainer([
            'dependencies' => [
                'factories' => [
                    'mailchimp.http' => function() use ($responses) {
                        return $this->getMockHttpClient($responses);
                    }
                ],
            ],
        ]);
    }
}
